==> qtjambi-webenginecore-6.4.4-sources.jar: io/qt/webengine/core/QWebEngineClientCertificateSelection.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>QWebEngineClientCertSelection class wraps a client certificate selection</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html">QWebEngineClientCertificateSelection</a></p>
 */
public final class QWebEngineClientCertificateSelection extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineClientCertificateSelection(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QWebEngineClientCertificateSelection instance, io.qt.webengine.core.QWebEngineClientCertificateSelection arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#certificates">QWebEngineClientCertificateSelection::certificates()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#host">QWebEngineClientCertificateSelection::host()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl host(){
        return host_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl host_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineClientCertificateSelection)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1) {
        assign(arg__1);
    }
    
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1){
        assign_native_cref_QWebEngineClientCertificateSelection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineClientCertificateSelection(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#select">QWebEngineClientCertificateSelection::select(QSslCertificate)</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void select(io.qt.network.@NonNull QSslCertificate certificate){
        select_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @QtUninvokable
    private native void select_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#selectNone">QWebEngineClientCertificateSelection::selectNone()</a></p>
     */
    @QtUninvokable
    public final void selectNone(){
        selectNone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void selectNone_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineClientCertificateSelection(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QWebEngineClientCertificateSelection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineClientCertificateSelection clone_native(long __this_nativeId);
}

==> qtjambi-webenginecore-6.5.0-sources.jar: io/qt/webengine/core/QWebEngineClientCertificateSelection.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>QWebEngineClientCertSelection class wraps a client certificate selection</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html">QWebEngineClientCertificateSelection</a></p>
 */
public class QWebEngineClientCertificateSelection extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineClientCertificateSelection(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QWebEngineClientCertificateSelection instance, io.qt.webengine.core.QWebEngineClientCertificateSelection arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#certificates">QWebEngineClientCertificateSelection::certificates()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#host">QWebEngineClientCertificateSelection::host()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl host(){
        return host_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl host_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineClientCertificateSelection)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1) {
        assign(arg__1);
    }
    
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineClientCertificateSelection arg__1){
        assign_native_cref_QWebEngineClientCertificateSelection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineClientCertificateSelection(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#select">QWebEngineClientCertificateSelection::select(QSslCertificate)</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void select(io.qt.network.@NonNull QSslCertificate certificate){
        select_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @QtUninvokable
    private native void select_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificateselection.html#selectNone">QWebEngineClientCertificateSelection::selectNone()</a></p>
     */
    @QtUninvokable
    public final void selectNone(){
        selectNone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void selectNone_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineClientCertificateSelection(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QWebEngineClientCertificateSelection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineClientCertificateSelection clone_native(long __this_nativeId);
}
